Opinion Search

# The Supreme Court of Ohio & The Ohio Judicial System

Reporter of Decisions - Opinions & Announcements

Opinion Search Filter Settings Use standard search logic for the full-text search.
Opinion Text Search: |  |
Source: |  |
Year Decided: |  |
County: |  |
Case Number: |  |
Author: |  |
Topics and Issues: |  |
WebCite No: | -Ohio- | WebCite and Citation are unique document searches. If a value is entered in the WebCite or Citation field, all other search filters are ignored. If values are entered in both the WebCite and Citation fields, only the WebCite search filter is applied.
Citation: |  |
| Hide Topics and Issues column | This search returned 376 rows. | Rows per page:
1 | 2 | 3 | 4 | 5 | 6 | 7 | 8
Case Caption | Case No. | Topics and Issues | Author | Citation / County | Decided | Posted | WebCite
--- | --- | --- | --- | --- | --- | --- | ---
07/30/2015 Case Announcements |  | Motion and procedural rulings. |  |  | 7/30/2015 | 7/30/2015 | 2015-Ohio-3021
07/29/2015 Case Announcements |  | Motion and procedural rulings. |  |  | 7/29/2015 | 7/29/2015 | 2015-Ohio-3025
07/28/2015 Case Announcements |  | Motion and procedural rulings. |  |  | 7/28/2015 | 7/28/2015 | 2015-Ohio-3016
In re Whitt | 2015-1200 | On certified entry of felony conviction. |  |  | 7/24/2015 | 7/24/2015 | 2015-Ohio-2947
07/24/2015 Case Announcements |  | Disciplinary cases. |  |  | 7/24/2015 | 7/24/2015 | 2015-Ohio-2963
07/24/2015 Case Announcements #2 |  | Motion and procedural rulings. |  |  | 7/24/2015 | 7/24/2015 | 2015-Ohio-2964
State ex rel. Jackson v. Calabrese (Slip Opinion) | 2014-1608 | Mandamus-R.C. 2969.25(C)-Failure to document balance of inmate account for six months preceding filing of petition-Judgment denying writ affirmed. | Per Curiam | Slip Opinion No. 2015-Ohio-2918 | 7/23/2015 | 7/23/2015 | 2015-Ohio-2918
Akron v. Ohio Dept. of Ins. (Slip Opinion) | 2014-0738 | Appeal dismissed as improvidently accepted. |  | Slip Opinion No. 2015-Ohio-2926 | 7/23/2015 | 7/23/2015 | 2015-Ohio-2926
Ohio Bur. of Workers' Comp. v. McKinley (Slip Opinion) | 2014-0795 | Appeal dismissed as improvidently accepted. |  | Slip Opinion No. 2015-Ohio-2927 | 7/23/2015 | 7/23/2015 | 2015-Ohio-2927
07/23/2015 Case Announcements |  | Merit decisions with opinions-Affidavits of disqualification-Motion and procedural rulings-Mediation matters. |  |  | 7/23/2015 | 7/23/2015 | 2015-Ohio-2943
State ex rel. Reeves v. Chief of Police, Cedar Point Police Dept. (Slip Opinion) | 2014-1850 | Mandamus-Public records-Affidavit of indigency-Affidavit must be notarized-Complaint must be verified-Denial of writ affirmed. | Per Curiam | Slip Opinion No. 2015-Ohio-2909 | 7/22/2015 | 7/22/2015 | 2015-Ohio-2909
07/22/2015 Case Announcements |  | Merit decisions with opinions-Affidavits of disqualification-Merit decisions without opinions-Motion and procedural rulings-Appeals accepted for review-Appeals not accepted for review-Reconsideration of prior decisions. |  |  | 7/22/2015 | 7/22/2015 | 2015-Ohio-2911
07/22/2015 Administrative Actions |  | Administrative actions. |  |  | 7/21/2015 | 7/22/2015 | 2015-Ohio-2921
State ex rel. Elkins v. Fais (Slip Opinion) | 2014-1663 | Procedendo-An available, though untaken, appeal is an adequate remedy at law that precludes an action in procedendo-Writ denied. | Per Curiam | Slip Opinion No. 2015-Ohio-2873 | 7/21/2015 | 7/21/2015 | 2015-Ohio-2873
07/21/2015 Case Announcements |  | Merit decisions with opinions-Affidavits of disqualification-Motion and procedural rulings. |  |  | 7/21/2015 | 7/21/2015 | 2015-Ohio-2908
07/21/2015 Case Announcements #2 |  | Motion and procedural rulings. |  |  | 7/21/2015 | 7/21/2015 | 2015-Ohio-2912
07/20/2015 Case Announcements |  | Official versions released-Motion and procedural rulings. |  |  | 7/20/2015 | 7/20/2015 | 2015-Ohio-2883
07/17/2015 Case Announcements |  | Motion and procedural rulings-Miscellaneous dismissals. |  |  | 7/17/2015 | 7/17/2015 | 2015-Ohio-2872
07/16/2015 Case Announcements |  | Merit decisions with opinions-Affidavits of disqualification-Disciplinary cases-Miscellaneous dismissals. |  |  | 7/16/2015 | 7/16/2015 | 2015-Ohio-2851
Bevins v. Richard (Slip Opinion) | 2014-1912 | Habeas corpus-Successive petition barred by res judicata-Judgment dismissing petition for writ affirmed. | Per Curiam | Slip Opinion No. 2015-Ohio-2832 | 7/16/2015 | 7/16/2015 | 2015-Ohio-2832
Turner v. Dept. of Rehab. & Corr. (Slip Opinion) | 2014-1569 | Mandamus-Adequate remedy in the ordinary course of the law-Judgment dismissing petition for writ affirmed. | Per Curiam | Slip Opinion No. 2015-Ohio-2833 | 7/16/2015 | 7/16/2015 | 2015-Ohio-2833
Metamora Elevator Co. v. Fulton Cty. Bd. of Revision (Slip Opinion) | 2014-0874 | In promulgating R.C. 5701.03, the General Assembly has expressly defined the term "business fixture" to include storage bins, and therefore, they are personal property not subject to real property tax. | O'Donnell, J. | Slip Opinion No. 2015-Ohio-2807 | 7/15/2015 | 7/15/2015 | 2015-Ohio-2807
Holloman v. Mohr (Slip Opinion) | 2014-1569 | Habeas corpus-Petition moot once petitioner has been released from incarceration-Judgment dismissing petition for writ affirmed. | Per Curiam | Slip Opinion No. 2015-Ohio-2812 | 7/15/2015 | 7/15/2015 | 2015-Ohio-2812
07/15/2015 Case Announcements |  | Merit decisions with opinions-Affidavits of disqualification. |  |  | 7/15/2015 | 7/15/2015 | 2015-Ohio-2837
07/14/2015 Case Announcements |  | Merit decisions with opinions-Affidavits of disqualification-Motion and procedural rulings. |  |  | 7/14/2015 | 7/14/2015 | 2015-Ohio-2831
Brooks v. Kelly (Slip Opinion) | 2014-1606 | Habeas corpus-Res judicata-Court of appeals' granting of summary judgment in favor of warden affirmed. | Per Curiam | Slip Opinion No. 2015-Ohio-2805 | 7/14/2015 | 7/14/2015 | 2015-Ohio-2805
Kuhn v. Kuhn (Slip Opinion) | 2014-0601 | Appeal dismissed as having been improvidently accepted. |  | Slip Opinion No. 2015-Ohio-2806 | 7/14/2015 | 7/14/2015 | 2015-Ohio-2806
Disciplinary Counsel v. Joseph | 2012-1107 | On petition for reinstatement. |  |  | 7/13/2015 | 7/13/2015 | 2015-Ohio-2775
Cleveland Metro. Bar Assn. v. Axner | 2014-1745 | On order to show cause. |  |  | 7/13/2015 | 7/13/2015 | 2015-Ohio-2776
Disciplinary Counsel v. Freeman | 2014-1755 | On order to show cause. |  |  | 7/13/2015 | 7/13/2015 | 2015-Ohio-2777
In re Resignation of Crosgrove | 2015-1059 | Attorneys at law-Resignation with disciplinary action pending-Gov.Bar R. VI(7)(C). |  |  | 7/13/2015 | 7/13/2015 | 2015-Ohio-2778
07/13/2015 Case Announcements |  | Disciplinary cases. |  |  | 7/13/2015 | 7/13/2015 | 2015-Ohio-2804
07/10/2015 Case Announcements |  | Motion and procedural rulings. |  |  | 7/10/2015 | 7/10/2015 | 2015-Ohio-2773
State ex rel. Smith v. McGee (Slip Opinion) | 2014-1009 | Mandamus-Procedendo-Adequate remedy in the ordinary course of the law-Court of appeals' dismissal of petition for writs affirmed. | Per Curiam | Slip Opinion No. 2015-Ohio-2748 | 7/9/2015 | 7/9/2015 | 2015-Ohio-2748
07/09/2015 Case Announcements |  | Merit decisions with opinions-Motion and procedural rulings-Miscellaneous dismissals. |  |  | 7/9/2015 | 7/9/2015 | 2015-Ohio-2755
07/09/2015 Case Announcements #2 |  | Motion and procedural rulings. |  |  | 7/9/2015 | 7/9/2015 | 2015-Ohio-2771
Cunningham v. Testa (Slip Opinion) | 2014-0532 | Taxation-Income-Domicile-R.C. 5747.24-Taxpayer's claim under R.C. 5747.24(B)(1) to be domiciled outside Ohio is not binding on tax commissioner when other statements support an Ohio domicile-Common-law principles for determining domicile still apply-Taxpayer's statement verifying non-Ohio domicile can be false if it is not supported by common law of domicile. | Pfeifer, J. | Slip Opinion No. 2015-Ohio-2744 | 7/8/2015 | 7/8/2015 | 2015-Ohio-2744
07/08/2015 Case Announcements |  | Merit decisions with opinions-Merit decisions without opinions-Motion and procedural rulings-Appeals accepted for review-Appeals not accepted for review-Reconsideration of prior decisions. |  |  | 7/8/2015 | 7/8/2015 | 2015-Ohio-2747
Cleveland Metro. Bar Assn. v. Sleibi (Slip Opinion) | 2014-1394 | Attorneys-Misconduct-Sexual activity with multiple clients-Violations of Prof.Cond.R. 1.8(j) and 8.4(h)-Sex addiction not a recognized mental disability for purposes of mitigation-Two-year suspension with six months stayed on conditions-Probation. | O'Neill, J. | Slip Opinion No. 2015-Ohio-2724 | 7/7/2015 | 7/7/2015 | 2015-Ohio-2724
07/07/2015 Case Announcements |  | Merit decisions with opinions. |  |  | 7/7/2015 | 7/7/2015 | 2015-Ohio-2745
07/06/2015 Case Announcements |  | Official versions released-Motion and procedural rulings. |  |  | 7/6/2015 | 7/6/2015 | 2015-Ohio-2719
Ginter v. Auglaize Cty. Bd. of Revision (Slip Opinion) | 2013-1710 | Taxation-Boards of revision do not have authority to dismiss a valuation complaint for failure to prosecute based on the complainant's failure to attend the scheduled hearing of the board-A board of revision must make a determination of value whenever a complaint properly invokes its jurisdiction. | Per Curiam | Slip Opinion No. 2015-Ohio-2571 | 7/2/2015 | 7/2/2015 | 2015-Ohio-2571
In Re Resignation of Lape | 2015-0919 | Attorneys at law-Resignation with disciplinary action pending-Gov.Bar R. VI(7)(C). |  |  | 7/2/2015 | 7/2/2015 | 2015-Ohio-2693
07/02/2015 Case Announcements |  | Merit decisions with opinions-Motion and procedural rulings-Disciplinary cases. |  |  | 7/2/2015 | 7/2/2015 | 2015-Ohio-2694
07/02/2015 Case Announcements #2 |  | Motion and procedural rulings. |  |  | 7/2/2015 | 7/2/2015 | 2015-Ohio-2721
Stark Cty. Bar Assn. v. Marinelli (Slip Opinion) | 2014-0971 | Attorney misconduct-Violations of the Rules of Professional Conduct, including failing to provide competent representation to clients and failing to act with reasonable diligence in representing clients-Two-year suspension, with one year stayed on conditions. | Per Curiam | Slip Opinion No. 2015-Ohio-2570 | 7/1/2015 | 7/1/2015 | 2015-Ohio-2570
07/01/2015 Case Announcements |  | Merit decisions with opinions-Motion and procedural rulings. |  |  | 7/1/2015 | 7/1/2015 | 2015-Ohio-2665
State ex rel. Oldaker v. Indus. Comm. (Slip Opinion) | 2014-0460 | Workers' Compensation-R.C. 4123.56(B)-Wage-loss compensation-Injured worker unable to return to former position must provide evidence of having made good-faith effort to search for comparably paying suitable employment. | Per Curiam | Slip Opinion No. 2015-Ohio-2569 | 6/30/2015 | 6/30/2015 | 2015-Ohio-2569
06/30/2015 Case Announcements |  | Merit decisions with opinions-Mediation matters. |  |  | 6/30/2015 | 6/30/2015 | 2015-Ohio-2583
06/29/2015 Case Announcements |  | Motion and procedural rulings-Miscellaneous dismissals. |  |  | 6/29/2015 | 6/29/2015 | 2015-Ohio-2567
1 | 2 | 3 | 4 | 5 | 6 | 7 | 8